diff gpp/settings.py @ 174:e9c718065a25

Ticket #58; use Django 1.2's cached template loader.
author Brian Neal <bgneal@gmail.com>
date Wed, 03 Mar 2010 04:04:11 +0000
parents a88041a84957
children 776028f4bced
line wrap: on
line diff
--- a/gpp/settings.py	Tue Mar 02 04:11:27 2010 +0000
+++ b/gpp/settings.py	Wed Mar 03 04:04:11 2010 +0000
@@ -58,11 +58,11 @@
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = local_settings.SECRET_KEY
 
 # List of callables that know how to import templates from various sources.
 TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.load_template_source',
-    'django.template.loaders.app_directories.load_template_source',
-#     'django.template.loaders.eggs.load_template_source',
+    ('django.template.loaders.cached.Loader', (
+        'django.template.loaders.filesystem.Loader',
+    )),
 )
 
 MIDDLEWARE_CLASSES = (
@@ -58,11 +58,11 @@
 SECRET_KEY = local_settings.SECRET_KEY
 
-# List of callables that know how to import templates from various sources.
+# List of Loader classes that know how to import templates from various sources.
 TEMPLATE_LOADERS = (